@@ -5,5 +5,5 @@ class NoTokenProvided(Exception):
 
 class GoatedApiException(Exception):
     def __init__(self, response):
-        self.message = f"The server returned an error. \n {response.text} "
+        self.message = f"The server returned an error. \n {response} "
         super().__init__(self.message)
